==> jbpm-quarkus-example-0.4.0-sources.jar: org/kie/kogito/examples/PersonValidationServiceRuleUnit.java <==
package org.kie.kogito.examples;

import org.drools.core.RuleBaseConfiguration;
import org.drools.core.SessionConfigurationImpl;
import org.drools.core.impl.EnvironmentImpl;
import org.kie.api.KieBaseConfiguration;
import org.kie.api.runtime.KieSession;

@javax.inject.Singleton()
public class PersonValidationServiceRuleUnit extends org.kie.kogito.rules.impl.AbstractRuleUnit<PersonValidationService> {

    public PersonValidationServiceRuleUnit() {
        this(new org.kie.kogito.examples.Application());
    }

    @javax.inject.Inject()
    public PersonValidationServiceRuleUnit(org.kie.kogito.Application app) {
        super(app);
    }

    public org.kie.kogito.examples.PersonValidationServiceRuleUnitInstance createInstance(PersonValidationService value) {
        return new org.kie.kogito.examples.PersonValidationServiceRuleUnitInstance(this, value, createLegacySession());
    }

    private org.kie.api.runtime.KieSession createLegacySession() {
        if (app.config() != null && app.config().rule() != null) {
            org.kie.kogito.rules.RuleConfig ruleCfg = app.config().rule();
            KieBaseConfiguration kieBaseConfiguration = new RuleBaseConfiguration();
            kieBaseConfiguration.setOption(ruleCfg.eventProcessingMode());
            org.drools.core.impl.InternalKnowledgeBase kb = org.drools.modelcompiler.builder.KieBaseBuilder.createKieBaseFromModel(new org.kie.kogito.examples.Rules471B42E068A21F8D5BEF529A54AE3B27_PersonValidationService(), kieBaseConfiguration);
            SessionConfigurationImpl sessionConfiguration = new SessionConfigurationImpl();
            sessionConfiguration.setOption(ruleCfg.clockType());
            KieSession ks = kb.newKieSession(sessionConfiguration, new EnvironmentImpl());
            org.kie.kogito.rules.RuleEventListenerConfig ruleEventListenerConfig = ruleCfg.ruleEventListeners();
            ruleEventListenerConfig.agendaListeners().forEach(ks::addEventListener);
            ruleEventListenerConfig.ruleRuntimeListeners().forEach(ks::addEventListener);
            return ks;
        } else {
            return org.drools.modelcompiler.builder.KieBaseBuilder.createKieBaseFromModel(new org.kie.kogito.examples.Rules471B42E068A21F8D5BEF529A54AE3B27_PersonValidationService()).newKieSession();
        }
    }
}

==> jbpm-quarkus-example-0.6.0-sources.jar: org/kie/kogito/examples/PersonValidationServiceRuleUnit.java <==
package org.kie.kogito.examples;

import org.drools.core.RuleBaseConfiguration;
import org.drools.core.SessionConfigurationImpl;
import org.drools.core.impl.EnvironmentImpl;
import org.drools.modelcompiler.builder.KieBaseBuilder;
import org.kie.api.KieBaseConfiguration;
import org.kie.api.runtime.KieSession;
import org.kie.kogito.Application;
import org.kie.kogito.rules.RuleEventListenerConfig;

@javax.inject.Singleton()
public class PersonValidationServiceRuleUnit extends org.kie.kogito.rules.impl.AbstractRuleUnit<PersonValidationService> {

    public PersonValidationServiceRuleUnit() {
        this(new org.kie.kogito.examples.Application());
    }

    @javax.inject.Inject()
    public PersonValidationServiceRuleUnit(org.kie.kogito.Application app) {
        super(app);
    }

    public org.kie.kogito.examples.PersonValidationServiceRuleUnitInstance internalCreateInstance(PersonValidationService value) {
        return new org.kie.kogito.examples.PersonValidationServiceRuleUnitInstance(this, value, createLegacySession());
    }

    private KieSession createLegacySession() {
        KieSession ks = app.ruleUnits().ruleRuntimeBuilder().newKieSession(PersonValidationService.class);
        ((org.drools.core.impl.StatefulKnowledgeSessionImpl) ks).setApplication(app);
        if (app.config() != null && app.config().rule() != null) {
            RuleEventListenerConfig ruleEventListenerConfig = app.config().rule().ruleEventListeners();
            ruleEventListenerConfig.agendaListeners().forEach(ks::addEventListener);
            ruleEventListenerConfig.ruleRuntimeListeners().forEach(ks::addEventListener);
        }
        return ks;
    }
}
